@@ -1,8 +1,3 @@
-from __future__ import (
-    absolute_import,
-    print_function,
-)
-
 import argparse
 import os
 
@@ -10,6 +5,7 @@ ap = argparse.ArgumentParser()
 ap.add_argument('path', nargs='+')
 opts = ap.parse_args()
 
+
 def gather():
     for p in opts.path:
         if not os.path.exists(p):
@@ -24,4 +20,5 @@ def gather():
         else:
             yield p
 
+
 print('\n'.join(sorted(gather(), key=lambda x: x.replace(os.path.sep, '/'))))
