@@ -1,10 +1,8 @@
-from __future__ import absolute_import
-
 import os
 import time
 
 
-class mocktime(object):
+class mocktime:
     def __init__(self, increment):
         self.time = 0
         self.increment = [float(s) for s in increment.split()]
